==> messaging-5.19.0-sources.jar: com/liveperson/messaging/commands/QueryMessagesUMSCommand.java <==
package com.liveperson.messaging.commands;

import com.liveperson.infra.LocalBroadcastReceiver;
import com.liveperson.infra.database.DataBaseExecutor;
import com.liveperson.infra.log.LPLog;
import com.liveperson.messaging.Messaging;
import com.liveperson.messaging.SocketTaskType;
import com.liveperson.messaging.commands.tasks.BaseAmsSocketConnectionCallback;
import com.liveperson.messaging.commands.tasks.MessagingEventSubscriptionManager;

/**
 * Created by shiranr on 14/01/2016.
 */
public class QueryMessagesUMSCommand extends BasicQueryMessagesCommand {

    private static final String TAG = "QueryMessagesUMSCommand";
    private int lastCurrentSequence;
    private LocalBroadcastReceiver mLocalBroadcastReceiver;

    public QueryMessagesUMSCommand(Messaging controller, String brandId, String conversationId, String dialogId, int lastCurrentSequence, boolean updateUI) {
        super(controller, brandId, conversationId, dialogId, updateUI);

        this.lastCurrentSequence = lastCurrentSequence;
    }

    @Override
    public void execute() {

        LPLog.INSTANCE.d(TAG,"Sending query messages from sequence " + lastCurrentSequence );
        controller.getMessagingEventSubscriptionManager().addSubscription(controller, brandID, conversationId, dialogId, lastCurrentSequence, mUpdateUI);
    }

    @Override
    public void setResponseCallBack(BaseAmsSocketConnectionCallback callBack) {
        super.setResponseCallBack(callBack);
        if (mLocalBroadcastReceiver == null) {
            mLocalBroadcastReceiver = new LocalBroadcastReceiver.Builder()
                    .addAction(MessagingEventSubscriptionManager.Companion.getMESSAGE_EVENT_COMPLETED() + dialogId)
                    .build((context, intent) -> {
                        mLocalBroadcastReceiver.unregister();
	                    LPLog.INSTANCE.d(TAG,"Got Message Event notification for dialog id: " + dialogId + " conversation ID: " + conversationId + ". Sending callback finished successfully");
                        if (intent.getBooleanExtra(MessagingEventSubscriptionManager.Companion.getSUCCESS(),false)){
                            DataBaseExecutor.execute(() -> mResponseCallBack.onTaskSuccess());
                        } else {
                            DataBaseExecutor.execute(() -> {
                                String key = MessagingEventSubscriptionManager.getERROR_MESSAGE();
                                String value = intent.getStringExtra(key);
                                Exception exception = new Exception(value);
                                mResponseCallBack.onTaskError(SocketTaskType.QUERY_MESSAGES, exception);
                            });

                        }
                    });
        }
        mLocalBroadcastReceiver.register();
    }


}

==> messaging-5.20.2-sources.jar: com/liveperson/messaging/commands/QueryMessagesUMSCommand.java <==
package com.liveperson.messaging.commands;

import com.liveperson.infra.LocalBroadcastReceiver;
import com.liveperson.infra.database.DataBaseExecutor;
import com.liveperson.infra.log.LPLog;
import com.liveperson.messaging.Messaging;
import com.liveperson.messaging.SocketTaskType;
import com.liveperson.messaging.commands.tasks.BaseAmsSocketConnectionCallback;
import com.liveperson.messaging.commands.tasks.MessagingEventSubscriptionManager;

/**
 * Created by shiranr on 14/01/2016.
 */
public class QueryMessagesUMSCommand extends BasicQueryMessagesCommand {

    private static final String TAG = "QueryMessagesUMSCommand";
    private int lastCurrentSequence;
    private LocalBroadcastReceiver mLocalBroadcastReceiver;

    public QueryMessagesUMSCommand(Messaging controller, String brandId, String conversationId, String dialogId, int lastCurrentSequence, boolean updateUI) {
        super(controller, brandId, conversationId, dialogId, updateUI);
        this.lastCurrentSequence = lastCurrentSequence;
    }



    @Override
    public void execute() {

        LPLog.INSTANCE.d(TAG,"Sending query messages from sequence " + lastCurrentSequence );
        controller.getMessagingEventSubscriptionManager().addSubscription(
                controller,
                brandID,
                conversationId,
                dialogId,
                lastCurrentSequence,
                mUpdateUI
        );
    }

    @Override
    public void setResponseCallBack(BaseAmsSocketConnectionCallback callBack) {
        super.setResponseCallBack(callBack);
        if (mLocalBroadcastReceiver == null) {
            mLocalBroadcastReceiver = new LocalBroadcastReceiver.Builder()
                    .addAction(MessagingEventSubscriptionManager.Companion.getMESSAGE_EVENT_COMPLETED() + dialogId)
                    .build((context, intent) -> {
                        mLocalBroadcastReceiver.unregister();
	                    LPLog.INSTANCE.d(TAG,"Got Message Event notification for dialog id: " + dialogId + " conversation ID: " + conversationId + ". Sending callback finished successfully");
                        if (intent.getBooleanExtra(MessagingEventSubscriptionManager.Companion.getSUCCESS(),false)){
                            DataBaseExecutor.execute(() -> mResponseCallBack.onTaskSuccess());
                        } else {
                            DataBaseExecutor.execute(() -> {
                                String key = MessagingEventSubscriptionManager.getERROR_MESSAGE();
                                String value = intent.getStringExtra(key);
                                Exception exception = new Exception(value);
                                mResponseCallBack.onTaskError(SocketTaskType.QUERY_MESSAGES, exception);
                            });

                        }
                    });
        }
        mLocalBroadcastReceiver.register();
    }


}
